@@ -2,12 +2,15 @@ if RUBY_VERSION >= '1.9'
   require 'simplecov'
   require 'coveralls'
 
-  SimpleCov.formatters = [SimpleCov::Formatter::HTMLFormatter, Coveralls::SimpleCov::Formatter]
+  SimpleCov.formatters = [
+    SimpleCov::Formatter::HTMLFormatter,
+    Coveralls::SimpleCov::Formatter
+  ]
 
   SimpleCov.start do
     add_filter '/spec/'
     add_filter '/vendor/'
-    minimum_coverage(92.93)
+    minimum_coverage(92.5)
   end
 end
 
@@ -32,7 +35,7 @@ class ExampleStrategy
   option :name, 'test'
 
   def call(env)
-    options[:dup] ? super : self.call!(env)
+    options[:dup] ? super : call!(env)
   end
 
   def initialize(*args, &block)
@@ -45,7 +48,7 @@ class ExampleStrategy
     @fail = fail!(options[:failure]) if options[:failure]
     @last_env = env
     return @fail if @fail
-    fail('Request Phase')
+    raise('Request Phase')
   end
 
   def callback_phase
@@ -53,6 +56,6 @@ class ExampleStrategy
     @fail = fail!(options[:failure]) if options[:failure]
     @last_env = env
     return @fail if @fail
-    fail('Callback Phase')
+    raise('Callback Phase')
   end
 end
